"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _Image = require("../Image");

describe('Image Component', function () {
  var sampleProps = {
    src: 'http://abc.com',
    placeholderSrc: 'http://xyz.com',
    alt: 'ABC',
    elementLocator: 'my-custom-image-locator'
  };
  test('should render correctly and match snapshots', function () {
    var image = (0, _enzyme.shallow)(_react.default.createElement(_Image.ImageVanilla, sampleProps));
    expect(image).toMatchSnapshot();
  });
  test('should change image src on error', function () {
    var image = (0, _enzyme.shallow)(_react.default.createElement(_Image.ImageVanilla, sampleProps));
    image.simulate('error', {
      target: image
    });
    expect(image.src).toBe(sampleProps.placeholderSrc);
  });
  test('should check the data attribute of image', function () {
    var image = (0, _enzyme.render)(_react.default.createElement(_Image.ImageVanilla, sampleProps));
    expect(image.attr('data-locator')).toEqual(sampleProps.elementLocator);
  });
  test('should check the default locator of image', function () {
    var props = {
      alt: 'my img tag'
    };
    var customLocator = 'image-my-img';
    var image = (0, _enzyme.render)(_react.default.createElement(_Image.ImageVanilla, props));
    expect(image.attr('data-locator')).toEqual(customLocator);
  });
});