import React from 'react';
import { shallow, render } from 'enzyme';
import { ButtonVanilla } from '../Button';
describe('Button Component', function () {
  var button = '';
  beforeEach(function () {
    button = shallow(React.createElement(ButtonVanilla, null, "Submit"));
  });
  test('should render correctly', function () {
    expect(button).toMatchSnapshot();
  });
  test('should render disabled', function () {
    button = shallow(React.createElement(ButtonVanilla, {
      disabled: true
    }, "Submit"));
    expect(button.find({
      disabled: true
    })).toHaveLength(1);
  });
  test('should render title element', function () {
    button = shallow(React.createElement(ButtonVanilla, {
      title: "tooltip"
    }, "Submit"));
    expect(button.find({
      title: 'tooltip'
    })).toHaveLength(1);
  });
  test('should render aria attribute element', function () {
    var ariaLabel = 'Custom Aria Label';
    button = shallow(React.createElement(ButtonVanilla, {
      ariaLabel: ariaLabel
    }, "Button"));
    expect(button.find({
      'aria-label': 'Custom Aria Label'
    })).toHaveLength(1);
  });
  test('should check the data attribute of button', function () {
    var sampleProps = {
      elementLocator: 'my-custom-button-locator',
      type: 'primary'
    };
    var buttonVanilla = render(React.createElement(ButtonVanilla, sampleProps));
    expect(buttonVanilla.attr('data-locator')).toEqual(sampleProps.elementLocator);
  });
});