import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { storiesOf } from '@storybook/react';
import defaultImage, { lazyLoadedImage, customImageLocator } from './Image.mock';
import Image, { ImageVanilla } from '.'; // $FlowFixMe eslint-disable-next-line extra-rules/no-commented-out-code

storiesOf('Atoms', module).addParameters({
  jest: ['Image']
}).addWithChapters('Image', {
  chapters: [{
    sections: [{
      sectionFn: function sectionFn() {
        return React.createElement(ImageVanilla, _extends({}, defaultImage, {
          className: "hide-default-sample"
        }));
      },
      options: {
        showSource: true,
        allowSourceToggling: true,
        showPropTables: true,
        allowPropTablesToggling: true
      }
    }]
  }, {
    title: 'Responsive Image Variations',
    sections: [{
      title: 'Default',
      sectionFn: function sectionFn() {
        return React.createElement(Image, defaultImage);
      }
    }, {
      title: 'Image with custom element locator',
      sectionFn: function sectionFn() {
        return React.createElement(Image, customImageLocator);
      }
    }]
  }, {
    title: 'Lazy loaded Image Variations',
    sections: [{
      title: 'Default lazy loaded',
      sectionFn: function sectionFn() {
        return React.createElement("p", {
          style: {
            height: '500px',
            color: 'blue'
          }
        }, "Scroll Down to lazy load image");
      }
    }, {
      title: 'This image will lazy load, check in network tab of chrome dev tools',
      info: 'Note: this only works in Chrome so far, check for updates here https://caniuse.com/#search=loading',
      sectionFn: function sectionFn() {
        return React.createElement(Image, lazyLoadedImage);
      }
    }]
  }]
});