import React from 'react';
import { shallow, render } from 'enzyme';
import { ImageVanilla } from '../Image';
describe('Image Component', function () {
  var sampleProps = {
    src: 'http://abc.com',
    placeholderSrc: 'http://xyz.com',
    alt: 'ABC',
    elementLocator: 'my-custom-image-locator'
  };
  test('should render correctly and match snapshots', function () {
    var image = shallow(React.createElement(ImageVanilla, sampleProps));
    expect(image).toMatchSnapshot();
  });
  test('should change image src on error', function () {
    var image = shallow(React.createElement(ImageVanilla, sampleProps));
    image.simulate('error', {
      target: image
    });
    expect(image.src).toBe(sampleProps.placeholderSrc);
  });
  test('should check the data attribute of image', function () {
    var image = render(React.createElement(ImageVanilla, sampleProps));
    expect(image.attr('data-locator')).toEqual(sampleProps.elementLocator);
  });
  test('should check the default locator of image', function () {
    var props = {
      alt: 'my img tag'
    };
    var customLocator = 'image-my-img';
    var image = render(React.createElement(ImageVanilla, props));
    expect(image.attr('data-locator')).toEqual(customLocator);
  });
});